@@ -1,5 +1,4 @@
-#ifndef TAGSMODEL_H
-#define TAGSMODEL_H
+#pragma once
 
 #include <MauiKit3/Core/fmh.h>
 #include <MauiKit3/Core/mauilist.h>
@@ -25,5 +24,3 @@ private:
     void packPreviewImages(FMH::MODEL &tag);
     QVariantList m_quickPlaces;
 };
-
-#endif // TAGSMODEL_H
